@@ -7,14 +7,13 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
-our $ISA     = qw/QDomCharacterData/;
+our $VERSION = '0.01_02';
+our $ISA     = qw/Qt::Xml::QDomCharacterData/;
 
 
 # FIXME: operator overload
 
 
-
 1;
 
 =head1 NAME
@@ -25,13 +24,20 @@ Qt::Xml::QDomComment
 
 =over
 
-=item    QDomComment()
+=item   QDomComment()
 
-=item    QDomComment(const QDomComment & x)
+=item   QDomComment()
 
-=item   QDomNode::NodeType nodeType()
+=item  QDomNode::NodeType nodeType()
 
-=item   QDomComment & operator=(const QDomComment & arg0)
+=item  QDomComment & operator=()
+
+
+=back
+
+=head1 ENUM VALUES
+
+=over
 
 
 =back
