@@ -7,14 +7,13 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
-our $ISA     = qw/QDomNode/;
+our $VERSION = '0.01_02';
+our $ISA     = qw/Qt::Xml::QDomNode/;
 
 
 # FIXME: operator overload
 
 
-
 1;
 
 =head1 NAME
@@ -25,13 +24,20 @@ Qt::Xml::QDomEntityReference
 
 =over
 
-=item    QDomEntityReference()
+=item   QDomEntityReference()
 
-=item    QDomEntityReference(const QDomEntityReference & x)
+=item   QDomEntityReference()
 
-=item   QDomNode::NodeType nodeType()
+=item  QDomNode::NodeType nodeType()
 
-=item   QDomEntityReference & operator=(const QDomEntityReference & arg0)
+=item  QDomEntityReference & operator=()
+
+
+=back
+
+=head1 ENUM VALUES
+
+=over
 
 
 =back
