@@ -7,14 +7,13 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
-our $ISA     = qw/QDomNode/;
+our $VERSION = '0.01_02';
+our $ISA     = qw/Qt::Xml::QDomNode/;
 
 
 # FIXME: operator overload
 
 
-
 1;
 
 =head1 NAME
@@ -25,17 +24,24 @@ Qt::Xml::QDomNotation
 
 =over
 
-=item    QDomNotation()
+=item   QDomNotation()
 
-=item    QDomNotation(const QDomNotation & x)
+=item   QDomNotation()
 
-=item   QDomNode::NodeType nodeType()
+=item  QDomNode::NodeType nodeType()
 
-=item   QDomNotation & operator=(const QDomNotation & arg0)
+=item  QDomNotation & operator=()
 
-=item   QString publicId()
+=item  QString publicId()
 
-=item   QString systemId()
+=item  QString systemId()
+
+
+=back
+
+=head1 ENUM VALUES
+
+=over
 
 
 =back
